Model
-----

.. automodule:: gordo.machine.model.base
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: gordo.machine.model.models
     :members:
     :undoc-members:
     :show-inheritance:
